# CytoBulk
Integrating transcriptional data to decipher the tumor microenvironment with the graph frequency domain model.


## Usage

To use cytobulk, please visit https://kristaxying.github.io/CytoBulk/

## 


### Maintainer
WANG Xueying xywang85-c@my.cityu.edu.hk

